MDT694B - Heros Devices 0.10.3 documentation

Skip to content
Back to top
View this page

# MDT694B

From: Thorlabs

Class: `herosdevices.hardware.thorlabs.mdt69xb.MDT694B`

Driver Quality Index: beta

Device driver for the MDT694B Single Channel, Open-Loop Piezo Controller.

Arguments

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.thorlabs.mdt69xb.MDT694B` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
address | <class ‘str’> |  | Serial address of the device.
timeout | <class ‘float’> | 1.0 | timeout for read operations.

Example JSON for BOSS

The following JSON strings can be used to start a HERO device representation of `MDT694B` using BOSS.

    {
        "_id": "my-piezo-controller",
        "classname": "herosdevices.hardware.thorlabs.MDT694B",
        "active": false,
        "arguments": {
            "address": "/dev/ttyUSB0"
        }
    }

from examples/thorlabs/mdt69xb.json

    {
        "_id": "my_MDT694B",
        "classname": "herosdevices.hardware.thorlabs.mdt69xb.MDT694B",
        "arguments": {
            "address": "/dev/ttyUSB0",
            "timeout": 1.0
        }
    }

generated from signature

Inheritance